.. _asn-gather:

asn_gather
==========

Copy members of an association from one location to another.

The association is copied into the destination, re-written such that the member
list points to the new location of the members.

Command Line
------------

.. code-block:: shell

   asn_gather --help

API
---

.. automodapi:: jwst.associations.asn_gather
